Running the example application
-------------------------------

In order to run the application, you have to enter the following commands in
your shell.

.. code-block:: bash
    
    $ git clone https://github.com/jugmac00/flask-reuploaded.git
    
    $ cd flask-reuploaded/examples

    $ cd example1  # or example2    

    $ # optional: create virtualenv

    $ pip install Flask-Reuploaded

    $ python app.py 


Then point your browser to `http://127.0.0.1:5000/`
